--
-- Mod: FS22_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersFieldPrices by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.0.0.2
-- 26-11-2021

RealNumbersFieldPrices = {};

function print_r (t, indent, done)
  done = done or {}
  indent = indent or ''
  local nextIndent -- Storage for next indentation value
  for key, value in pairs (t) do
    if type (value) == "table" and not done [value] then
      nextIndent = nextIndent or
          (indent .. string.rep(' ',string.len(tostring (key))+2))
          -- Shortcut conditional allocation
      done [value] = true
      print (indent .. "[" .. tostring (key) .. "] => Table {");
      print  (nextIndent .. "{");
      print_r (value, nextIndent .. string.rep(' ',2), done)
      print  (nextIndent .. "}");
    else
      print  (indent .. "[" .. tostring (key) .. "] => " .. tostring (value).."")
    end
  end
end

function RealNumbersFieldPrices:loadMap(name)
	RN = {};
	RN.notRunYetRealNumbersFieldPrices = true;
	RN.upStartRealNumbersFieldPrices = true;
	
	RN.farmlandOwnerType = {};
	RN.fieldPrices = {};
	RN.fieldPrices.pricePerHa 		= 25000;	-- default RLN value = 25000 eu/ha farmland - not per field ha. Vanilla game = 60000 eu/ha
	RN.fieldPrices.rentPriceScale 	= 0.03;		-- default RLN value = 0.03 (3% of farmland price)
	RN.fieldPrices.permitFieldRent = true;		-- default RLN vaulue = true. Change to false if not allowed
	RN.farmlandForLease = {2, 5, 9, 13, 15, 18, 21, 25, 29, 33, 36, 38, 40, 45, 48, 52, 55, 57}; 	-- farmland indices - not field indices


--[[ 	

To identify fields you want to define as rentable, run the script and press lAlt-rf in the game.
A list of farmland information is printed to the log file. Find the farmland, that the field belongs to, 
and enter the farmland index into the list above. If there are multiple fields in one farmland, all fields
belonging to this farmland will be rentable. This is because only farmland is traded, not individual fields.

--]]	
	print("\n --- RealNumbersFieldPrices.lua started --- \n");

end;


function RealNumbersFieldPrices:keyEvent(unicode, sym, modifier, isDown)
	local farmland = {};
	local farmlandArea = 0;
	local farmlandId = 0;
	local isOwned = false;
	local fieldId = 0;
	local fieldArea = 0;
	local fruitTypeIndex = 0;
	local fruitType = {};
	

	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_f) then


			print("\n --- RealNumbersFieldPrices.lua started --- \n");

			if g_fieldManager.farmlandIdFieldMapping ~= nil then
				for i, land in pairs(g_fieldManager.farmlandIdFieldMapping) do

					for k, field in pairs(land) do
						farmland = field.farmland;
						farmlandArea = farmland.areaInHa;
						farmlandId = farmland.id;
						isOwned = farmland.isOwned;
						fieldId = field.fieldId;
						fieldArea = field.fieldArea;
						fruitTypeIndex = field.fruitType;
						fruitType = g_fruitTypeManager:getFruitTypeByIndex(fruitTypeIndex);
						if fruitType ~= nil then
							fruitName = fruitType.name;
						else
							fruitName = "Undefined";
						end;
						farmland.price =  RN.fieldPrices.pricePerHa * farmlandArea;
						RN.farmlandOwnerType[i] = "For sale";	
						if RN.fieldPrices.permitFieldRent then 
							if #RN.farmlandForLease > 0 then
								for j =  1,#RN.farmlandForLease do						    
									if RN.farmlandForLease[j] == farmlandId then
										farmland.price =  RN.fieldPrices.rentPriceScale * RN.fieldPrices.pricePerHa * farmlandArea;
										RN.farmlandOwnerType[i] = "For rent";		
									end;
								end;
							end;
						end;	
						print(" ");
						if isOwned then
							print(" field id:   "..fieldId.." Area (Ha):"..fieldArea.." Crop: "..fruitName.." Is owned = true");
						else
							print(" field id:   "..fieldId.." Area (Ha):"..fieldArea.." Crop: "..fruitName.." Is owned = false");
						end;
					end;
					print("farmland id: "..farmlandId.." Area (Ha): "..farmlandArea.." Price: "..farmland.price.." Ownership: "..RN.farmlandOwnerType[i]);
				end;
			else
				print("g_fieldManager.farmlandIdFieldMapping do not exists")
			end;
			print("\n --- RealNumbersFieldPrices.lua updates every 10 min --- \n");
	end;
end;

function RealNumbersFieldPrices:update(dt)
	local minute = g_currentMission.environment.currentMinute;
	local runMinute = minute % 10; -- remainder
	if runMinute ~= 4 then RN.notRunYetRealNumbersFieldPrices = true; end;
	if runMinute == 4 or RN.upStartRealNumbersFieldPrices then
		if RN.notRunYetRealNumbersFieldPrices then
			if g_fieldManager.fields ~= nil then
				g_farmlandManager.pricePerHa = 25000;
			end;

			if g_fieldManager.farmlandIdFieldMapping ~= nil then

				for i, land in pairs(g_fieldManager.farmlandIdFieldMapping) do
					for k, field in pairs(land) do
						local farmland = field.farmland;
						local farmlandArea = farmland.areaInHa;
						local farmlandId = farmland.id;
						local isOwned = farmland.isOwned;
						local fieldId = field.fieldId;
						local fieldArea = field.fieldArea;
						local fruitTypeIndex = field.fruitType;
						local fruitType = g_fruitTypeManager:getFruitTypeByIndex(fruitTypeIndex);
						if fruitType ~= nil then
							fruitName = fruitType.name;
						else
							fruitName = "Undefined";
						end;
						RN.farmlandOwnerType[i] = "For sale";						
						farmland.price =  RN.fieldPrices.pricePerHa * farmlandArea;
						if RN.fieldPrices.permitFieldRent then
							if #RN.farmlandForLease > 0 then
								for j =  1,#RN.farmlandForLease do						    
									if RN.farmlandForLease[j] == farmlandId then
										farmland.price =  RN.fieldPrices.rentPriceScale * RN.fieldPrices.pricePerHa * farmlandArea;
										RN.farmlandOwnerType[i] = "For rent";		
									end;
								end;
							end;
						end;
					end;
				end;
			end;
		end;
		RN.notRunYetRealNumbersFieldPrices = false;
		RN.upStartRealNumbersFieldPrices = false;	
	end;
end;
function RealNumbersFieldPrices:draw()
end;
function RealNumbersFieldPrices:deleteMap()
end;
function RealNumbersFieldPrices:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersFieldPrices);







